<a id="autonomy.chain.constants"></a>

# autonomy.chain.constants

Chain constants

<a id="autonomy.chain.constants.CONTRACTS_DIR_LOCAL"></a>

#### CONTRACTS`_`DIR`_`LOCAL

use from an editable/local installation

<a id="autonomy.chain.constants.ERC20_TOKEN_ADDRESS_LOCAL"></a>

#### ERC20`_`TOKEN`_`ADDRESS`_`LOCAL

nosec

<a id="autonomy.chain.constants.ContractAddresses"></a>

## ContractAddresses Objects

```python
@dataclass
class ContractAddresses()
```

Contract addresses container for a chain.

<a id="autonomy.chain.constants.ContractAddresses.get"></a>

#### get

```python
def get(name: str) -> str
```

Returns the contract address.

